👋 Quick start - ngff-zarr
Description: Installation: Command line conversion: NumPy array to OME-Zarr:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# 👋 Quick start

## Installation

    pip install "ngff-zarr[cli]"

## Command line conversion

    ngff-zarr -i ./cthead1.png -o ./cthead1.ome.zarr

## NumPy array to OME-Zarr

    import ngff_zarr as nz
    import numpy as np

    data = np.random.randint(0, 256, int(1e6)).reshape((1000, 1000))
    multiscales = nz.to_multiscales(data)
    nz.to_ngff_zarr('example.ome.zarr', multiscales)